<!--This documentation was autogenerated with `python -m royalnet.generate -f markdown`.-->

# `royalnet.backpack`

A Pack that is imported by default by all Royalnet instances.

Keep things here to a minimum!

## Commands

### `version`

Display the current Royalnet version.

### `exception`

Raise an exception in the command.

### `excevent`

Call an event that raises an exception.

## Events

### `exception`

## Page Stars

### `/api/royalnet/version`

## Exception Stars

## Tables

### `telegram`

### `discord`

### `users`

